@@ -329,7 +329,7 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 	}
 
 #ifdef USE_GTKFILECHOOSER
-	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert HTML File") : _("Insert Text File"),
+	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert: HTML File") : _("Insert: Text File"),
 						       NULL,
 						       GTK_FILE_CHOOSER_ACTION_OPEN,
 						       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -338,7 +338,7 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 	gtk_dialog_set_default_response (GTK_DIALOG (cd->file_dialog), GTK_RESPONSE_OK);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (cd->file_dialog), g_get_home_dir ());
 #else
-	cd->file_dialog = gtk_file_selection_new (html ? _("Insert HTML File") : _("Insert Text File"));
+	cd->file_dialog = gtk_file_selection_new (html ? _("Insert: HTML File") : _("Insert: Text File"));
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (cd->file_dialog), "~/");
 #endif
 
@@ -688,26 +688,17 @@ menubar_set_languages (GtkHTMLControlData *cd)
 	GString *str;
 	gboolean enabled;
 	gint i;
-	gint no_of_lang=0;
 
-	if (!cd->languages) {
-		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "0", NULL);
+	if (!cd->languages)
 		return;
-	}
 
 	str = g_string_new (NULL);
 	cd->block_language_changes = TRUE;
 	for (i = 0; i < cd->languages->_length; i ++) {
 		enabled = cd->language && strstr (cd->language, cd->languages->_buffer [i].abbreviation) != NULL;
-		if (enabled)
-			no_of_lang++;
 		g_string_printf (str, "/commands/SpellLanguage%d", i + 1);
 		bonobo_ui_component_set_prop (cd->uic, str->str, "state", enabled ? "1" : "0", NULL);
 	}
-	if (no_of_lang > 0)
-		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "1", NULL);
-	else
-		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "0", NULL);
 	g_string_free (str, TRUE);
 	cd->block_language_changes = FALSE;
 }
