@@ -168,12 +168,16 @@ html_engine_select_region (HTMLEngine *e,
 	if (e->clue == NULL)
 		return;
 
+	/* printf ("selection %d,%d x %d,%d\n", x1, y1, x2, y2); */
+
 	a = html_engine_get_point_at (e, x1, y1, TRUE);
 	b = html_engine_get_point_at (e, x2, y2, TRUE);
 
 	if (a && b) {
 		HTMLInterval *new_selection;
 
+		/* printf ("points offsets %d, %d\n", a->offset, b->offset); */
+
 		new_selection = html_interval_new_from_points (a, b);
 		html_interval_validate (new_selection);
 		html_engine_select_interval (e, new_selection);
@@ -242,7 +246,7 @@ html_engine_unselect_all (HTMLEngine *e)
 static void
 remove_mark (HTMLEngine *e)
 {
-	if (e->editable) {
+	if (e->editable || e->caret_mode) {
 		if (e->mark == NULL)
 			return;
 
@@ -348,7 +352,12 @@ gboolean
 html_engine_is_selection_active (HTMLEngine *e)
 {
 	html_engine_edit_selection_updater_do_idle (e->selection_updater);
-	return e->selection ? TRUE : FALSE;
+	if (e->selection) {
+		g_return_val_if_fail (!html_engine_get_editable (e) || e->mark, FALSE);
+		return (!html_engine_get_editable (e) || e->mark) ? TRUE : FALSE;
+	}
+
+	return FALSE;
 }
 
 static void
